import ApolloClient from 'apollo-client';
import { SchemaLink } from 'apollo-link-schema';
import { REGISTER_PROVIDER_QUERY } from '../queries';
import { PROVIDER_DEFINITION_MUTATION, UPDATE_MODEL_MUTATION } from '../mutations';
import { InMemoryCache } from 'apollo-cache-inmemory';
import { withClientState } from 'apollo-link-state';
import { ApolloLink } from 'apollo-link';
import { makeExecutableSchema, addMockFunctionsToSchema } from 'graphql-tools';
import { schema as typeDefs } from '../schema';
import { resolvers } from '../resolvers';

const defaultSchema = `
type Query {
    dummy: Int
}
type Mutation {
    dummy: Int
}
`;

const cache = new InMemoryCache();

const linkState = withClientState({
    cache,
    resolvers,
    typeDefs: defaultSchema.concat(typeDefs),
});
const links = [linkState];

const client = new ApolloClient({
    queryDeduplication: true,
    // dataIdFromObject: (result) => modules.getDataIdFromObject(result),
    link: ApolloLink.from(links),
    cache,
});

export {
    client,
};



